@@ -124,10 +124,15 @@ class CronWorkflow:
                 entrypoint=self.workflow_template_ref,
                 volumes=[],
                 volume_claim_templates=[],
+                parallelism=self.parallelism,
             )
         else:
             self.spec = IoArgoprojWorkflowV1alpha1WorkflowSpec(
-                templates=[self.template], entrypoint=self.name, volumes=[], volume_claim_templates=[]
+                templates=[self.template],
+                entrypoint=self.name,
+                volumes=[],
+                volume_claim_templates=[],
+                parallelism=self.parallelism,
             )
 
         if ttl_strategy:
